==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/Filterfields_Type.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;


/**
 * <p>Classe Java pour filterfields_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="filterfields_Type">
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.w3.org/2001/XMLSchema>string">
 *       &lt;attribute name="jsonclass" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "filterfields_Type", propOrder = {
    "value"
})
public class Filterfields_Type {

    @XmlValue
    protected String value;
    @XmlAttribute(name = "jsonclass")
    protected String jsonclass;

    /**
     * Obtient la valeur de la propriété value.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getValue() {
        return value;
    }

    /**
     * Définit la valeur de la propriété value.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setValue(String value) {
        this.value = value;
    }

    /**
     * Obtient la valeur de la propriété jsonclass.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJsonclass() {
        return jsonclass;
    }

    /**
     * Définit la valeur de la propriété jsonclass.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJsonclass(String value) {
        this.jsonclass = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/Filterfields_Type.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;


/**
 * <p>Java class for filterfields_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="filterfields_Type">
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.w3.org/2001/XMLSchema>string">
 *       &lt;attribute name="jsonclass" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "filterfields_Type", propOrder = {
    "value"
})
public class Filterfields_Type {

    @XmlValue
    protected String value;
    @XmlAttribute(name = "jsonclass")
    protected String jsonclass;

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setValue(String value) {
        this.value = value;
    }

    /**
     * Gets the value of the jsonclass property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJsonclass() {
        return jsonclass;
    }

    /**
     * Sets the value of the jsonclass property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJsonclass(String value) {
        this.jsonclass = value;
    }

}
